@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Canonical, Ltd.
+ * Copyright (C) 2014-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -63,7 +63,7 @@ size_t stress_get_pagesize(void)
 		return page_size;
 
 #if defined(_SC_PAGESIZE)
-        sz = sysconf(_SC_PAGESIZE);
+	sz = sysconf(_SC_PAGESIZE);
 	page_size = (sz <= 0) ? PAGE_4K : (size_t)sz;
 #else
 	page_size = PAGE_4K;
@@ -248,7 +248,6 @@ void stress_parent_died_alarm(void)
  */
 int stress_process_dumpable(const bool dumpable)
 {
-	char path[PATH_MAX];
 	int fd, rc = 0;
 #if defined(RLIMIT_CORE)
 	struct rlimit lim = { 0, 0 };
@@ -256,12 +255,18 @@ int stress_process_dumpable(const bool dumpable)
 	(void)setrlimit(RLIMIT_CORE, &lim);
 #endif
 
-#if defined(__linux__) && defined(PR_SET_DUMPABLE)
+	/*
+	 *  changing PR_SET_DUMPABLE also affects the
+	 *  oom adjust capability, so for now, we disable
+	 *  this as I'd rather have a oom'able process when
+	 *  memory gets contrained. Don't enable this
+	 *  unless one checks that processes able oomable!
+	 */
+#if 0 && defined(__linux__) && defined(PR_SET_DUMPABLE)
 	(void)prctl(PR_SET_DUMPABLE,
 		dumpable ? SUID_DUMP_USER : SUID_DUMP_DISABLE);
 #endif
-	snprintf(path, sizeof(path), "/proc/%d/coredump_filter", (int)getpid());
-	if ((fd = open(path, O_WRONLY)) >= 0) {
+	if ((fd = open("/proc/self/coredump_filter", O_WRONLY)) >= 0) {
 		char const *str =
 			dumpable ? "0x33" : "0x00";
 
@@ -391,18 +396,18 @@ int stress_set_temp_path(char *path)
  *      construct a temp filename
  */
 int stress_temp_filename(
-        char *path,
-        const size_t len,
-        const char *name,
-        const pid_t pid,
-        const uint32_t instance,
-        const uint64_t magic)
+	char *path,
+	const size_t len,
+	const char *name,
+	const pid_t pid,
+	const uint32_t instance,
+	const uint64_t magic)
 {
 	return snprintf(path, len, "%s/tmp-%s-%d-%"
 		PRIu32 "/%s-%d-%"
-                PRIu32 "-%" PRIu64,
+		PRIu32 "-%" PRIu64,
 		stress_temp_path,
-                name, (int)pid, instance,
+		name, (int)pid, instance,
 		name, (int)pid, instance, magic);
 }
 
@@ -412,10 +417,10 @@ int stress_temp_filename(
  */
 int stress_temp_dir(
 	char *path,
-        const size_t len,
+	const size_t len,
 	const char *name,
-        const pid_t pid,
-        const uint32_t instance)
+	const pid_t pid,
+	const uint32_t instance)
 {
 	return snprintf(path, len, "%s/tmp-%s-%d-%" PRIu32,
 		stress_temp_path, name, (int)pid, instance);
@@ -427,8 +432,8 @@ int stress_temp_dir(
  */
 int stress_temp_dir_mk(
 	const char *name,
-        const pid_t pid,
-        const uint32_t instance)
+	const pid_t pid,
+	const uint32_t instance)
 {
 	int ret;
 	char tmp[PATH_MAX];
@@ -449,8 +454,8 @@ int stress_temp_dir_mk(
  */
 int stress_temp_dir_rm(
 	const char *name,
-        const pid_t pid,
-        const uint32_t instance)
+	const pid_t pid,
+	const uint32_t instance)
 {
 	int ret;
 	char tmp[PATH_MAX + 1];
@@ -478,7 +483,7 @@ void stress_cwd_readwriteable(void)
 		return;
 	}
 	if (access(path, R_OK | W_OK)) {
-		pr_inf(stderr, "Working directory %s is not read/writeable, "
+		pr_inf(stdout, "Working directory %s is not read/writeable, "
 			"some I/O tests may fail\n", path);
 		return;
 	}
@@ -599,7 +604,7 @@ int stress_cache_alloc(const char *name)
 	cpu_caches = get_all_cpu_cache_details();
 	if (!cpu_caches) {
 		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
-			pr_inf(stderr, "%s: using built-in defaults as unable to "
+			pr_inf(stdout, "%s: using built-in defaults as unable to "
 				"determine cache details\n", name);
 		shared->mem_cache_size = MEM_CACHE_SIZE;
 		goto init_done;
@@ -618,7 +623,7 @@ int stress_cache_alloc(const char *name)
 	cache = get_cpu_cache(cpu_caches, shared->mem_cache_level);
 	if (!cache) {
 		if (warn_once(WARN_ONCE_CACHE_NONE))
-			pr_inf(stderr, "%s: using built-in defaults as no suitable "
+			pr_inf(stdout, "%s: using built-in defaults as no suitable "
 				"cache found\n", name);
 		shared->mem_cache_size = MEM_CACHE_SIZE;
 		goto init_done;
@@ -629,7 +634,7 @@ int stress_cache_alloc(const char *name)
 
 		if (shared->mem_cache_ways > cache->ways) {
 			if (warn_once(WARN_ONCE_CACHE_WAY))
-				pr_inf(stderr, "%s: cache way value too high - "
+				pr_inf(stdout, "%s: cache way value too high - "
 					"defaulting to %d (the maximum)\n",
 					name, cache->ways);
 			shared->mem_cache_ways = cache->ways;
@@ -646,7 +651,7 @@ int stress_cache_alloc(const char *name)
 
 	if (!shared->mem_cache_size) {
 		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
-			pr_inf(stderr, "%s: using built-in defaults as "
+			pr_inf(stdout, "%s: using built-in defaults as "
 				"unable to determine cache size\n", name);
 		shared->mem_cache_size = MEM_CACHE_SIZE;
 	}
@@ -660,7 +665,7 @@ init_done:
 		return -1;
 	}
 	if (warn_once(WARN_ONCE_CACHE_SIZE))
-		pr_inf(stderr, "%s: default cache size: %" PRIu64 "K\n",
+		pr_inf(stdout, "%s: default cache size: %" PRIu64 "K\n",
 			name, shared->mem_cache_size / 1024);
 
 	return 0;
@@ -731,17 +736,17 @@ int system_read(
  */
 static inline bool stress_is_prime64(uint64_t n)
 {
-        register uint64_t i, max;
+	register uint64_t i, max;
 
-        if (n <= 3)
-                return n >= 2;
-        if ((n % 2 == 0) || (n % 3 == 0))
-                return false;
-        max = sqrt(n) + 1;
-        for (i = 5; i < max; i+= 6)
-                if ((n % i == 0) || (n % (i + 2) == 0))
-                        return false;
-        return true;
+	if (n <= 3)
+		return n >= 2;
+	if ((n % 2 == 0) || (n % 3 == 0))
+		return false;
+	max = sqrt(n) + 1;
+	for (i = 5; i < max; i+= 6)
+		if ((n % i == 0) || (n % (i + 2) == 0))
+			return false;
+	return true;
 }
 
 /*
@@ -850,10 +855,10 @@ unsigned int stress_get_cpu(void)
  *	on a particular arch or kernel
  */
 int stress_not_implemented(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	(void)counter;
 	(void)instance;
@@ -863,12 +868,12 @@ int stress_not_implemented(
 	struct utsname buf;
 
 	if (!uname(&buf)) {
-		pr_inf(stderr, "%s: this stressor is not implemented on this system: %s %s %s\n",
+		pr_inf(stdout, "%s: this stressor is not implemented on this system: %s %s %s\n",
 			name, buf.machine, buf.sysname, buf.release);
 		return EXIT_NOT_IMPLEMENTED;
 	}
 #endif
-	pr_inf(stderr, "%s: this stressor is not implemented on this system\n",
+	pr_inf(stdout, "%s: this stressor is not implemented on this system\n",
 		name);
 	return EXIT_NOT_IMPLEMENTED;
 }
