@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -85,7 +85,7 @@ int stress_cache(
 			pinned = true;
 
 	if (pinned) {
-		pr_inf(stderr, "%s: can't get sched affinity, pinning to "
+		pr_inf(stdout, "%s: can't get sched affinity, pinning to "
 			"CPU %d (instance %" PRIu32 ")\n",
 			name, sched_getcpu(), pinned);
 	}
