@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -273,7 +273,7 @@ int stress_clone(
 		}
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-	pr_inf(stderr, "%s: created a maximum of %" PRIu64 " clones\n",
+	pr_inf(stdout, "%s: created a maximum of %" PRIu64 " clones\n",
 		name, max_clones);
 
 	/* And reap */
