@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@
 #define STACK_SIZE	(16384)
 
 #if !defined(__gnu_hurd__) && !defined(__minix__)
-uint8_t stack_sig[SIGSTKSZ + SIGSTKSZ];	/* ensure we have a sig stack */
+static uint8_t stack_sig[SIGSTKSZ + SIGSTKSZ];	/* ensure we have a sig stack */
 #endif
 
 static ucontext_t uctx_main, uctx_thread1, uctx_thread2, uctx_thread3;
@@ -103,10 +103,10 @@ int stress_context(
 
 #if !defined(__gnu_hurd__) && !defined(__minix__)
 	/*
-         *  We should use an alterative stack, for
-         *  Linux we probably should use SS_AUTODISARM
+	 *  we should use an alterative stack, for
+	 *  Linux we probably should use SS_AUTODISARM
 	 *  if it is available
-         */
+	 */
 	memset(stack_sig, 0, sizeof(stack_sig));
 	ss.ss_sp = (void *)align_address(stack_sig, STACK_ALIGNMENT);
 	ss.ss_size = SIGSTKSZ;
@@ -115,10 +115,10 @@ int stress_context(
 #else
 	ss.ss_flags = 0;
 #endif
-        if (sigaltstack(&ss, NULL) < 0) {
-                pr_fail_err(name, "sigaltstack");
-                return EXIT_FAILURE;
-        }
+	if (sigaltstack(&ss, NULL) < 0) {
+		pr_fail_err(name, "sigaltstack");
+		return EXIT_FAILURE;
+	}
 #endif
 	__counter = 0;
 	__max_ops = max_ops * 1000;
