@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,10 +40,10 @@
 int stress_icmp_flood_supported(void)
 {
 	if (geteuid() != 0) {
-                pr_inf(stderr, "icmp flood stressor will be skipped, "
-                        "need to be running as root for this stressor\n");
-                return -1;
-        }
+		pr_inf(stdout, "icmp flood stressor will be skipped, "
+			"need to be running as root for this stressor\n");
+		return -1;
+	}
 	return 0;
 }
 
@@ -161,7 +161,7 @@ err:
 
 int stress_icmp_flood_supported(void)
 {
-	pr_inf(stderr, "icmp flood stressor will be skipped, not supported on this machine\n");
+	pr_inf(stdout, "icmp flood stressor will be skipped, not supported on this machine\n");
 	return -1;
 }
 
