@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -68,7 +68,7 @@ int stress_klog(
 	}
 	if (len > (ssize_t)(4 * MB)) {
 		if (!instance)
-			pr_inf(stderr, "%s: truncating syslog buffer to 4MB\n", name);
+			pr_inf(stdout, "%s: truncating syslog buffer to 4MB\n", name);
 		len  = 4 * MB;
 	}
 	buffer = malloc((size_t)len);
