@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,8 +67,18 @@ static void *stress_membarrier_thread(void *arg)
 		return &nowt;
 	}
 	while (keep_running && opt_do_run) {
+		int ret;
+
+		ret = shim_membarrier(MEMBARRIER_CMD_QUERY, 0);
+		if (ret < 0) {
+			pr_fail_err(ctxt->name, "membarrier CMD QUERY");
+			break;
+		}
+		/* CMD SHARED not availble; skip it */
+		if (!(ret & MEMBARRIER_CMD_SHARED))
+			continue;
 		if (shim_membarrier(MEMBARRIER_CMD_SHARED, 0) < 0) {
-			pr_fail_err(ctxt->name, "membarrier");
+			pr_fail_err(ctxt->name, "membarrier CMD SHARED");
 			break;
 		}
 	}
@@ -101,7 +111,7 @@ int stress_membarrier(
 		return EXIT_FAILURE;
 	}
 	if (!(ret & MEMBARRIER_CMD_SHARED)) {
-		pr_inf(stderr, "%s: membarrier MEMBARRIER_CMD_SHARED "
+		pr_inf(stdout, "%s: membarrier MEMBARRIER_CMD_SHARED "
 			"not supported\n", name);
 		return EXIT_FAILURE;
 	}
