@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,7 +73,7 @@ int stress_mknod(
 	int ret;
 
 	if (num_nodes == 0) {
-		pr_inf(stderr, "%s: aborting, no valid mknod modes.\n",
+		pr_err(stderr, "%s: aborting, no valid mknod modes.\n",
 			name);
 		return EXIT_FAILURE;
 	}
