@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -424,7 +424,6 @@ extern void pr_openlog(const char *filename);
 #endif
 #define DEFAULT_MEMFD_BYTES	(256 * MB)
 
-
 #define MIN_MERGESORT_SIZE	(1 * KB)
 #define MAX_MERGESORT_SIZE	(4 * MB)
 #define DEFAULT_MERGESORT_SIZE	(256 * KB)
@@ -535,7 +534,6 @@ extern void pr_openlog(const char *filename);
 #endif
 #define DEFAULT_SYNC_FILE_BYTES	(1 * GB)
 
-
 #define MIN_TSEARCH_SIZE	(1 * KB)
 #define MAX_TSEARCH_SIZE	(4 * MB)
 #define DEFAULT_TSEARCH_SIZE	(64 * KB)
@@ -606,6 +604,7 @@ extern void pr_openlog(const char *filename);
 #define STRESS_CPU_DITHER_X	(1024)
 #define STRESS_CPU_DITHER_Y	(768)
 
+/* Generic bit setting on an array macros */
 #define STRESS_NBITS(a)		(sizeof(a[0]) * 8)
 #define STRESS_GETBIT(a, i)	(a[i / STRESS_NBITS(a)] & \
 				 (1 << (i & (STRESS_NBITS(a)-1))))
@@ -623,15 +622,17 @@ extern void pr_openlog(const char *filename);
 
 #define SIZEOF_ARRAY(a)		(sizeof(a) / sizeof(a[0]))
 
+#if defined(__linux__)
+#define STRESS_THRASH
+#endif
+
+/* Arch specific, x86 */
 #if defined(__x86_64__) || defined(__x86_64) || \
     defined(__i386__) || defined(__i386)
 #define STRESS_X86	1
 #endif
 
-#if defined(__linux__)
-#define STRESS_THRASH
-#endif
-
+/* Arch specific, ARM */
 #if defined(__ARM_ARCH_6__) || defined(__ARM_ARCH_6J__) ||     \
     defined(__ARM_ARCH_6K__) || defined(__ARM_ARCH_6Z__) ||    \
     defined(__ARM_ARCH_6ZK__) || defined(__ARM_ARCH_6T2__) ||  \
@@ -866,7 +867,6 @@ typedef struct {
 #endif
 } proc_stats_t;
 
-
 /* Shared memory segment */
 typedef struct {
 	size_t length;					/* Size of segment */
@@ -963,6 +963,7 @@ typedef enum {
 	STRESS_FIFO,
 	STRESS_FILENAME,
 	STRESS_FLOCK,
+	STRESS_FANOTIFY,
 	STRESS_FORK,
 	STRESS_FP_ERROR,
 	STRESS_FSTAT,
@@ -1010,6 +1011,7 @@ typedef enum {
 	STRESS_MSG,
 	STRESS_MSYNC,
 	STRESS_MQ,
+	STRESS_NETLINK_PROC,
 	STRESS_NICE,
 	STRESS_NULL,
 	STRESS_NUMA,
@@ -1078,6 +1080,7 @@ typedef enum {
 	STRESS_UTIME,
 	STRESS_VECMATH,
 	STRESS_VFORK,
+	STRESS_VFORKMANY,
 	STRESS_VM,
 	STRESS_VM_RW,
 	STRESS_VM_SPLICE,
@@ -1276,6 +1279,9 @@ typedef enum {
 	OPT_FLOCK,
 	OPT_FLOCK_OPS,
 
+	OPT_FANOTIFY,
+	OPT_FANOTIFY_OPS,
+
 	OPT_FORK_OPS,
 	OPT_FORK_MAX,
 
@@ -1454,6 +1460,9 @@ typedef enum {
 	OPT_MQ_OPS,
 	OPT_MQ_SIZE,
 
+	OPT_NETLINK_PROC,
+	OPT_NETLINK_PROC_OPS,
+
 	OPT_NICE,
 	OPT_NICE_OPS,
 
@@ -1721,6 +1730,9 @@ typedef enum {
 	OPT_VFORK_OPS,
 	OPT_VFORK_MAX,
 
+	OPT_VFORKMANY,
+	OPT_VFORKMANY_OPS,
+
 	OPT_VM_BYTES,
 	OPT_VM_HANG,
 	OPT_VM_KEEP,
@@ -1770,6 +1782,7 @@ typedef struct {
 	const uint32_t class;		/* class of stress test */
 } stress_t;
 
+/* Per process information */
 typedef struct {
 	pid_t	*pids;			/* process id */
 	int32_t started_procs;		/* count of started processes */
@@ -1778,12 +1791,14 @@ typedef struct {
 	bool	exclude;		/* true if excluded */
 } proc_info_t;
 
+/* Scale lookup mapping, suffix -> scale by */
 typedef struct {
 	const char	ch;		/* Scaling suffix */
 	const uint64_t	scale;		/* Amount to scale by */
 } scale_t;
 
 #if defined(__linux__)
+/* Cache types */
 typedef enum cache_type {
 	CACHE_TYPE_UNKNOWN = 0,
 	CACHE_TYPE_DATA,
@@ -1791,6 +1806,7 @@ typedef enum cache_type {
 	CACHE_TYPE_UNIFIED,
 } cache_type_t;
 
+/* CPU cache information */
 typedef struct cpu_cache {
 	uint16_t           level;
 	cache_type_t       type;
@@ -1838,11 +1854,19 @@ extern uint64_t uint64_zero(void);
 static volatile uint64_t uint64_val;
 static volatile double   double_val;
 
+/*
+ *  uint64_put()
+ *	stash a uint64_t value
+ */
 static inline void uint64_put(const uint64_t a)
 {
 	uint64_val = a;
 }
 
+/*
+ *  double_put()
+ *	stash a double value
+ */
 static inline void double_put(const double a)
 {
 	double_val = a;
@@ -1863,18 +1887,22 @@ extern void stress_cwd_readwriteable(void);
 extern const char *stress_strsignal(const int signum);
 
 #if defined(STRESS_X86)
-
+/*
+ *  clflush()
+ *	flush a cache line
+ */
 static inline void clflush(volatile void *ptr)
 {
         asm volatile("clflush %0" : "+m" (*(volatile char *)ptr));
 }
-
 #else
-
 #define clflush(ptr)	do { } while (0) /* No-op */
-
 #endif
 
+/*
+ *  mfence()
+ *	serializing memory fence
+ */
 static inline void mfence(void)
 {
 #if NEED_GNUC(4, 2, 0)
@@ -1911,16 +1939,28 @@ static inline uint32_t mwc32(void)
 	return (__mwc.z << 16) + __mwc.w;
 }
 
+/*
+ *  mwc64()
+ *	get a 64 bit pseudo random number
+ */
 static inline uint64_t mwc64(void)
 {
 	return (((uint64_t)mwc32()) << 32) | mwc32();
 }
 
+/*
+ *  mwc16()
+ *	get a 16 bit pseudo random number
+ */
 static inline uint16_t mwc16(void)
 {
 	return mwc32() & 0xffff;
 }
 
+/*
+ *  mwc8()
+ *	get an 8 bit pseudo random number
+ */
 static inline uint8_t mwc8(void)
 {
 	return mwc32() & 0xff;
@@ -2039,7 +2079,6 @@ static inline int exit_status(const int err)
 static inline WARN_UNUSED void *align_stack(void *stack_top)
 {
 	return (void *)((uintptr_t)stack_top & ~(uintptr_t)0xf);
-
 }
 
 /*
@@ -2133,6 +2172,7 @@ extern void stress_set_fifo_readers(const char *optarg);
 extern int  stress_filename_opts(const char *opt);
 extern void stress_set_fiemap_size(const char *optarg);
 extern void stress_set_fork_max(const char *optarg);
+extern int  stress_fanotify_supported(void);
 extern void stress_set_fstat_dir(const char *optarg);
 extern void stress_set_hdd_bytes(const char *optarg);
 extern int  stress_hdd_opts(char *opts);
@@ -2154,6 +2194,7 @@ extern void stress_set_mmap_bytes(const char *optarg);
 extern void stress_set_mq_size(const char *optarg);
 extern void stress_set_mremap_bytes(const char *optarg);
 extern void stress_set_msync_bytes(const char *optarg);
+extern int  stress_netlink_proc_supported(void);
 extern void stress_set_pipe_data_size(const char *optarg);
 extern void stress_set_pipe_size(const char *optarg);
 extern void stress_set_pthread_max(const char *optarg);
@@ -2283,6 +2324,7 @@ extern int shim_mlock2(const void *addr, size_t len, int flags);
 extern int shim_usleep(uint64_t usec);
 extern char *shim_getlogin(void);
 extern int shim_msync(void *addr, size_t length, int flags);
+extern int shim_sysfs(int option, ...);
 
 #define STRESS(func)							\
 extern int func(uint64_t *const counter, const uint32_t instance,	\
@@ -2328,6 +2370,7 @@ STRESS(stress_fiemap);
 STRESS(stress_fifo);
 STRESS(stress_filename);
 STRESS(stress_flock);
+STRESS(stress_fanotify);
 STRESS(stress_fork);
 STRESS(stress_fp_error);
 STRESS(stress_fstat);
@@ -2375,6 +2418,7 @@ STRESS(stress_mremap);
 STRESS(stress_msg);
 STRESS(stress_msync);
 STRESS(stress_mq);
+STRESS(stress_netlink_proc);
 STRESS(stress_nice);
 STRESS(stress_noop);
 STRESS(stress_null);
@@ -2444,6 +2488,7 @@ STRESS(stress_userfaultfd);
 STRESS(stress_utime);
 STRESS(stress_vecmath);
 STRESS(stress_vfork);
+STRESS(stress_vforkmany);
 STRESS(stress_vm);
 STRESS(stress_vm_rw);
 STRESS(stress_vm_splice);
