@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,12 +31,14 @@
     defined(__NR_move_pages) &&		\
     defined(__NR_set_mempolicy)
 
-#define NUMA_LONG_BITS		(sizeof(unsigned long) * 8)
+#define BITS_PER_BYTE		(8)
+#define NUMA_LONG_BITS		(sizeof(unsigned long) * BITS_PER_BYTE)
 
 #define MPOL_DEFAULT		(0)
 #define MPOL_PREFERRED		(1)
 #define MPOL_BIND		(2)
 #define MPOL_INTERLEAVE		(3)
+#define MPOL_LOCAL		(4)
 
 #define MPOL_F_NODE		(1 << 0)
 #define MPOL_F_ADDR		(1 << 1)
@@ -46,7 +48,6 @@
 #define MPOL_MF_MOVE		(1 << 1)
 #define MPOL_MF_MOVE_ALL	(1 << 2)
 
-#define SYS_NODE_PATH	"/sys/devices/system/node"
 #define MMAP_SZ			(4 * MB)
 
 typedef struct node {
@@ -54,6 +55,34 @@ typedef struct node {
 	struct node	*next;
 } node_t;
 
+/*
+ *  stress_numa_get_max_nodes()
+ *	probe for maximum number of nodes
+ */
+static unsigned long stress_numa_get_max_nodes(void)
+{
+	unsigned long sz = BITS_PER_BYTE, *mask = NULL;
+
+	do {
+		int mode = 0;
+		unsigned long *newmask = realloc(mask, sz / BITS_PER_BYTE);
+
+		if (!newmask)
+			break;
+		mask = newmask;
+		if (shim_get_mempolicy(&mode, mask, sz, 0, 0) == 0)
+			goto done;
+		sz <<= 1;
+	} while (sz < 0x100000 && errno == EINVAL);
+
+	/* Failed */
+	sz = 0;
+done:
+	free(mask);
+
+	return sz;
+}
+
 /*
  *  stress_numa_free_nodes()
  *	free circular list of node info
@@ -74,46 +103,87 @@ static void stress_numa_free_nodes(node_t *nodes)
 }
 
 /*
- *  stress_numa_get_nodes(void)
- *	collect number of nodes, add them to a
+ *  hex_to_int()
+ *	convert ASCII hex digit to integer
+ */
+static inline int hex_to_int(const char ch)
+{
+	if (ch >= '0' && ch <= '9')
+		return ch - '0';
+	if (ch >= 'a' && ch <= 'f')
+		return ch - 'a' + 10;
+	if (ch >= 'A' && ch <= 'F')
+		return ch - 'F' + 10;
+	return -1;
+}
+
+/*
+ *  stress_numa_get_mem_nodes(void)
+ *	collect number of NUMA memory nodes, add them to a
  *	circular linked list
  */
-static int stress_numa_get_nodes(node_t **node_ptr)
+static int stress_numa_get_mem_nodes(node_t **node_ptr)
 {
-	DIR *dir;
-	struct dirent *entry;
-	unsigned long n = 0;
+	FILE *fp;
+	unsigned long n = 0, node_id = 0;
 	node_t *tail = NULL;
 	*node_ptr = NULL;
+	char buffer[8192], *str = NULL, *ptr;
 
-	dir = opendir(SYS_NODE_PATH);
-	if (!dir)
+	fp = fopen("/proc/self/status", "r");
+	if (!fp)
 		return -1;
 
-	while ((entry = readdir(dir)) != NULL) {
-		uint32_t node_id;
-		node_t *node;
-
-		if (strncmp(entry->d_name, "node", 4))
-			continue;
-		if (!isdigit(entry->d_name[4]))
-			continue;
-		if (sscanf(&entry->d_name[4], "%u10", &node_id) != 1)
-			continue;
-
-		node = calloc(1, sizeof(*node));
-		if (!node) {
+	while (fgets(buffer, sizeof(buffer), fp)) {
+		if (!strncmp(buffer, "Mems_allowed:", 13)) {
+			str = buffer + 13;
 			break;
 		}
-		node->node_id = node_id;
-		node->next = *node_ptr;
-		*node_ptr = node;
-		if (!tail)
-			tail = node;
-		tail->next = node;
-		n++;
 	}
-	(void)closedir(dir);
+	(void)fclose(fp);
+
+	if (!str)
+		return -1;
+
+	ptr = buffer + strlen(buffer) - 2;
+
+	/*
+	 *  Parse hex digits into NUMA node ids, these
+	 *  are listed with least significant node last
+	 *  so we need to scan backwards from the end of
+	 *  the string back to the start.
+	 */
+	while (*ptr != ' ' && (ptr > str)) {
+		int val, i;
+
+		/* Skip commas */
+		if (*ptr == ',') {
+			ptr--;
+			continue;
+		}
+
+		val = hex_to_int(*ptr);
+		if (val < 0)
+			return -1;
+
+		/* Each hex digit represent 4 memory nodes */
+		for (i = 0; i < 4; i++) {
+			if (val & (1 << i)) {
+				node_t *node = calloc(1, sizeof(*node));
+				if (!node)
+					return -1;
+				node->node_id = node_id;
+				node->next = *node_ptr;
+				*node_ptr = node;
+				if (!tail)
+					tail = node;
+				tail->next = node;
+				n++;
+			}
+			node_id++;
+		}
+		ptr--;
+	}
 
 	return n;
 }
@@ -123,31 +193,39 @@ static int stress_numa_get_nodes(node_t **node_ptr)
  *	stress the Linux NUMA interfaces
  */
 int stress_numa(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	long numa_nodes;
-	unsigned long max_nodes, nbits, lbits = 8 * sizeof(unsigned long);
-	uint8_t *buf;
-	const pid_t mypid = getpid();
+	unsigned long max_nodes;
+	const unsigned long lbits = NUMA_LONG_BITS;
 	const unsigned long page_sz = stress_get_pagesize();
 	const unsigned long num_pages = MMAP_SZ / page_sz;
+	uint8_t *buf;
 	node_t *n;
+	const pid_t mypid = getpid();
 	int rc = EXIT_FAILURE;
 
-	(void)instance;
-
-	numa_nodes = stress_numa_get_nodes(&n);
-	if (numa_nodes <= 1) {
-		pr_inf(stderr, "%s: multiple NUMA nodes not found, "
-			"aborting test.\n", name);
-		rc = EXIT_SUCCESS;
+	numa_nodes = stress_numa_get_mem_nodes(&n);
+	if (numa_nodes < 1) {
+		pr_inf(stdout, "%s: no NUMA nodes not found, "
+			"aborting test\n", name);
+		rc = EXIT_NO_RESOURCE;
 		goto numa_free;
 	}
-	nbits = (numa_nodes + lbits - 1) / lbits;
-	max_nodes = nbits * lbits;
+	max_nodes = stress_numa_get_max_nodes();
+	if (max_nodes == 0) {
+		pr_inf(stderr, "%s: cannot determine maximum number "
+			"of NUMA nodes, aborting test\n", name);
+		rc = EXIT_NO_RESOURCE;
+		goto numa_free;
+	}
+	if (!instance) {
+		pr_inf(stdout, "%s: system has %lu of a maximum %lu memory NUMA nodes\n",
+			name, numa_nodes, max_nodes);
+	}
 
 	/*
 	 *  We need a buffer to migrate around NUMA nodes
@@ -176,15 +254,15 @@ int stress_numa(
 			(unsigned long)buf, MPOL_F_ADDR);
 		if (ret < 0) {
 			pr_fail_err(name, "get_mempolicy");
+			goto err;
 		}
 		if (!opt_do_run)
 			break;
 
-		memset(node_mask, 0, sizeof(node_mask));
-		STRESS_SETBIT(node_mask, n->node_id);
-		ret = shim_set_mempolicy(MPOL_PREFERRED, node_mask, max_nodes);
+		ret = shim_set_mempolicy(MPOL_PREFERRED, NULL, max_nodes);
 		if (ret < 0) {
 			pr_fail_err(name, "set_mempolicy");
+			goto err;
 		}
 		memset(buf, 0xff, MMAP_SZ);
 		if (!opt_do_run)
@@ -205,8 +283,10 @@ int stress_numa(
 		ret = shim_mbind(buf, MMAP_SZ, MPOL_BIND, node_mask,
 			max_nodes, MPOL_MF_STRICT);
 		if (ret < 0) {
-			if (errno != EIO)
+			if (errno != EIO) {
 				pr_fail_err(name, "mbind");
+				goto err;
+			}
 		} else {
 			memset(buf, 0xaa, MMAP_SZ);
 		}
@@ -221,8 +301,10 @@ int stress_numa(
 		ret = shim_mbind(buf, MMAP_SZ, MPOL_BIND, node_mask,
 			max_nodes, MPOL_DEFAULT);
 		if (ret < 0) {
-			if (errno != EIO)
+			if (errno != EIO) {
 				pr_fail_err(name, "mbind");
+				goto err;
+			}
 		} else {
 			memset(buf, 0x5c, MMAP_SZ);
 		}
@@ -242,6 +324,7 @@ int stress_numa(
 			old_node_mask, node_mask);
 		if (ret < 0) {
 			pr_fail_err(name, "migrate_pages");
+			goto err;
 		}
 		if (!opt_do_run)
 			break;
@@ -260,6 +343,7 @@ int stress_numa(
 				dest_nodes, status, MPOL_MF_MOVE);
 			if (ret < 0) {
 				pr_fail_err(name, "move_pages");
+				goto err;
 			}
 			memset(buf, j, MMAP_SZ);
 			if (!opt_do_run)
@@ -269,6 +353,7 @@ int stress_numa(
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 	rc = EXIT_SUCCESS;
+err:
 	munmap(buf, MMAP_SZ);
 numa_free:
 	stress_numa_free_nodes(n);
@@ -277,10 +362,10 @@ numa_free:
 }
 #else
 int stress_numa(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	return stress_not_implemented(counter, instance, max_ops, name);
 }
