@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,9 +38,8 @@ static size_t opt_pipe_data_size = 512;
  */
 void stress_set_pipe_size(const char *optarg)
 {
-        opt_pipe_size = (size_t)get_uint64_byte(optarg);
-        check_range("pipe-size", opt_pipe_size,
-               4, 1024 * 1024);
+	opt_pipe_size = (size_t)get_uint64_byte(optarg);
+	check_range("pipe-size", opt_pipe_size, 4, 1024 * 1024);
 }
 #endif
 
@@ -50,9 +49,9 @@ void stress_set_pipe_size(const char *optarg)
  */
 void stress_set_pipe_data_size(const char *optarg)
 {
-        opt_pipe_data_size = (size_t)get_uint64_byte(optarg);
-        check_range("pipe-data_size", opt_pipe_data_size,
-                4, stress_get_pagesize());
+	opt_pipe_data_size = (size_t)get_uint64_byte(optarg);
+	check_range("pipe-data_size", opt_pipe_data_size,
+		4, stress_get_pagesize());
 }
 
 /*
