@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -71,7 +71,7 @@ static int do_quotactl(
 		static int failed_mask = 0;
 
 		if (errno == EPERM) {
-			pr_inf(stderr, "%s: need CAP_SYS_ADMIN capability to "
+			pr_inf(stdout, "%s: need CAP_SYS_ADMIN capability to "
 				"run quota stressor, aborting stress test\n",
 				name);
 			return errno;
