@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,14 +43,14 @@ int stress_rdrand_supported(void)
 	if (!((memcmp(&ebx, "Genu", 4) == 0) &&
 	      (memcmp(&edx, "ineI", 4) == 0) &&
 	      (memcmp(&ecx, "ntel", 4) == 0))) {
-		pr_inf(stderr, "rdrand stressor will be skipped, "
+		pr_inf(stdout, "rdrand stressor will be skipped, "
 			"not a recognised Intel CPU.\n");
 		return -1;
 	}
 	/* ..and supports rdrand? */
 	__cpuid(1, eax, ebx, ecx, edx);
 	if (!(ecx & 0x40000000)) {
-		pr_inf(stderr, "rdrand stressor will be skipped, CPU "
+		pr_inf(stdout, "rdrand stressor will be skipped, CPU "
 			"does not support the rdrand instruction.\n");
 		return -1;
 	}
@@ -64,13 +64,13 @@ int stress_rdrand_supported(void)
  */
 static inline uint64_t rdrand64(void)
 {
-        uint64_t        ret;
+	uint64_t        ret;
 
-        asm volatile("1:;\n\
-        rdrand %0;\n\
-        jnc 1b;\n":"=r"(ret));
+	asm volatile("1:;\n\
+	rdrand %0;\n\
+	jnc 1b;\n":"=r"(ret));
 
-        return ret;
+	return ret;
 }
 
 /*
@@ -117,10 +117,10 @@ static inline uint64_t rdrand64(void)
  *      stress Intel rdrand instruction
  */
 int stress_rdrand(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	if (rdrand_supported) {
 		double time_start, duration, billion_bits;
@@ -154,7 +154,7 @@ int stress_rdrand(
  */
 int stress_rdrand_supported(void)
 {
-	pr_inf(stderr, "rdrand stressor will be skipped, CPU does not "
+	pr_inf(stdout, "rdrand stressor will be skipped, CPU does not "
 		"support the rdrand instruction.\n");
 	return -1;
 }
@@ -164,10 +164,10 @@ int stress_rdrand_supported(void)
  *      no-op for non-intel
  */
 int stress_rdrand(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	return stress_not_implemented(counter, instance, max_ops, name);
 }
