@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,19 +29,19 @@
 
 static const int policies[] = {
 #if defined(SCHED_IDLE)
-        SCHED_IDLE,
+	SCHED_IDLE,
 #endif
 #if defined(SCHED_FIFO)
-        SCHED_FIFO,
+	SCHED_FIFO,
 #endif
 #if defined(SCHED_RR)
-        SCHED_RR,
+	SCHED_RR,
 #endif
 #if defined(SCHED_OTHER)
-        SCHED_OTHER,
+	SCHED_OTHER,
 #endif
 #if defined(SCHED_BATCH)
-        SCHED_BATCH,
+	SCHED_BATCH,
 #endif
 };
 
@@ -56,7 +56,7 @@ int stress_schedpolicy(
 
 	if (SIZEOF_ARRAY(policies) == 0) {
 		if (instance == 0) {
-			pr_inf(stderr, "%s: no scheduling policies "
+			pr_inf(stdout, "%s: no scheduling policies "
 				"available, skipping test\n",
 				name);
 		}
