@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,10 +38,13 @@
 	BPF_STMT(BPF_RET+BPF_K, SECCOMP_RET_ALLOW)
 
 static struct sock_filter filter_allow_write[] = {
-        BPF_STMT(BPF_LD+BPF_W+BPF_ABS, SYSCALL_NR),
+	BPF_STMT(BPF_LD+BPF_W+BPF_ABS, SYSCALL_NR),
 #if defined(__NR_open)
 	ALLOW_SYSCALL(open),
 #endif
+#if defined(__NR_openat)
+	ALLOW_SYSCALL(openat),
+#endif
 #if defined(__NR_write)
 	ALLOW_SYSCALL(write),
 #endif
@@ -58,10 +61,13 @@ static struct sock_filter filter_allow_write[] = {
 };
 
 static struct sock_filter filter[] = {
-        BPF_STMT(BPF_LD+BPF_W+BPF_ABS, SYSCALL_NR),
+	BPF_STMT(BPF_LD+BPF_W+BPF_ABS, SYSCALL_NR),
 #if defined(__NR_open)
 	ALLOW_SYSCALL(open),
 #endif
+#if defined(__NR_openat)
+	ALLOW_SYSCALL(openat),
+#endif
 #if defined(__NR_close)
 	ALLOW_SYSCALL(close),
 #endif
@@ -229,18 +235,20 @@ int stress_seccomp(
 				}
 				/* ..exited OK but we expected SIGSYS death? */
 				if (WIFEXITED(status) && !allow_write) {
-					pr_fail_err(name,
-						"expecting SIGSYS seccomp trap "
+					pr_fail(stderr,
+						"%s: expecting SIGSYS seccomp trap "
 						"but got a successful exit which "
-						"was not expected");
+						"was not expected\n",
+						name);
 				}
 				/* ..exited with a SIGSYS but we expexted OK exit? */
 				if (WIFSIGNALED(status) && allow_write) {
 					if (WTERMSIG(status) == SIGSYS) {
-						pr_fail_err(name,
-							"expecting a successful exit "
+						pr_fail(stderr,
+							"%s: expecting a successful exit "
 							"but got a seccomp SIGSYS "
-							"which was not expected");
+							"which was not expected\n",
+							name);
 					}
 				}
 			}
