@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,7 +81,7 @@ void stress_semaphore_sysv_init(void)
 	}
 
 	if (opt_sequential) {
-		pr_inf(stderr, "semaphore init (System V) failed: errno=%d: "
+		pr_inf(stdout, "semaphore init (System V) failed: errno=%d: "
 			"(%s), skipping semaphore stressor\n",
 			errno, strerror(errno));
 	} else {
@@ -135,7 +135,7 @@ static void semaphore_sysv_thrash(
 
 			if (semtimedop(sem_id, &semwait, 1, &timeout) < 0) {
 				if (errno == EAGAIN) {
-					pr_inf(stderr, "Semaphore timed out: errno=%d (%s)\n",
+					pr_inf(stdout, "Semaphore timed out: errno=%d (%s)\n",
 						errno, strerror(errno));
 					goto timed_out;
 				}
@@ -286,7 +286,7 @@ reap:
 		if (pids[i] > 0) {
 			int status;
 
-                        (void)waitpid(pids[i], &status, 0);
+			(void)waitpid(pids[i], &status, 0);
 		}
 	}
 
