@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,7 +54,7 @@ void stress_semaphore_posix_init(void)
 	}
 
 	if (opt_sequential) {
-		pr_inf(stderr, "semaphore init (POSIX) failed: errno=%d: "
+		pr_inf(stdout, "semaphore init (POSIX) failed: errno=%d: "
 			"(%s), skipping semaphore stressor\n",
 			errno, strerror(errno));
 	} else {
@@ -69,7 +69,7 @@ void stress_semaphore_posix_init(void)
  */
 void stress_semaphore_posix_destroy(void)
 {
-        if (shared->sem_posix.init) {
+	if (shared->sem_posix.init) {
 		if (sem_destroy(&shared->sem_posix.sem) < 0) {
 			pr_err(stderr, "semaphore destroy failed: errno=%d (%s)\n",
 				errno, strerror(errno));
@@ -191,7 +191,7 @@ reap:
 		if (pids[i] > 0) {
 			int status;
 
-                        (void)waitpid(pids[i], &status, 0);
+			(void)waitpid(pids[i], &status, 0);
 		}
 	}
 
