@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -320,7 +320,7 @@ static int stress_sctp_server(
 #if defined(SOCKET_NODELAY)
 			if (opt_flags & OPT_FLAGS_SOCKET_NODELAY) {
 				if (setsockopt(fd, SOL_TCP, TCP_NODELAY, &one, sizeof(one)) < 0) {
-					pr_inf(stderr, "%s: setsockopt TCP_NODELAY "
+					pr_inf(stdout, "%s: setsockopt TCP_NODELAY "
 						"failed and disabled, errno=%d (%s)\n",
 						name, errno, strerror(errno));
 					opt_flags &= ~OPT_FLAGS_SOCKET_NODELAY;
