@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,9 +52,9 @@ int stress_spawn(
 	 *  spawnutable as root.
 	 */
 	if (geteuid() == 0) {
-		pr_inf(stderr, "%s: running as root, won't run test.\n", name);
+		pr_inf(stdout, "%s: running as root, won't run test.\n", name);
 		return EXIT_FAILURE;
-        }
+	}
 
 	/*
 	 *  Determine our own self as the spawnutable, e.g. run stress-ng
