@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -124,7 +124,7 @@ static void *stress_sys_rw_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
 	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-        stack_t ss;
+	stack_t ss;
 	ctxt_t *ctxt = (ctxt_t *)ctxt_ptr;
 
 	/*
@@ -268,7 +268,7 @@ int stress_sysfs(
 
 	if (geteuid() == 0) {
 		if (instance == 0) {
-			pr_inf(stderr, "%s: running as root, just traversing /sys "
+			pr_inf(stdout, "%s: running as root, just traversing /sys "
 				"and not read/writing to /sys files.\n", name);
 		}
 		sys_rw = false;
