@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2016 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,14 +43,14 @@ int stress_tsc_supported(void)
 	if (!((memcmp(&ebx, "Genu", 4) == 0) &&
 	      (memcmp(&edx, "ineI", 4) == 0) &&
 	      (memcmp(&ecx, "ntel", 4) == 0))) {
-		pr_inf(stderr, "tsc stressor will be skipped, "
+		pr_inf(stdout, "tsc stressor will be skipped, "
 			"not a recognised Intel CPU.\n");
 		return -1;
 	}
 	/* ..and supports tsc? */
 	__cpuid(1, eax, ebx, ecx, edx);
 	if (!(edx & 0x10)) {
-		pr_inf(stderr, "tsc stressor will be skipped, CPU "
+		pr_inf(stdout, "tsc stressor will be skipped, CPU "
 			"does not support the rdtsc instruction.\n");
 		return -1;
 	}
@@ -64,9 +64,9 @@ int stress_tsc_supported(void)
 static inline void rdtsc(void)
 {
 #if STRESS_TSC_SERIALIZED
-        asm volatile("cpuid\nrdtsc\n" : : : "%edx", "%eax");
+	asm volatile("cpuid\nrdtsc\n" : : : "%edx", "%eax");
 #else
-        asm volatile("rdtsc\n" : : : "%edx", "%eax");
+	asm volatile("rdtsc\n" : : : "%edx", "%eax");
 #endif
 }
 
@@ -114,10 +114,10 @@ static inline void rdtsc(void)
  *      stress Intel tsc instruction
  */
 int stress_tsc(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	(void)instance;
 	(void)name;
@@ -142,7 +142,7 @@ int stress_tsc(
  */
 int stress_tsc_supported(void)
 {
-	pr_inf(stderr, "tsc stressor will be skipped, CPU does not "
+	pr_inf(stdout, "tsc stressor will be skipped, CPU does not "
 		"support the tsc instruction.\n");
 	return -1;
 }
@@ -152,10 +152,10 @@ int stress_tsc_supported(void)
  *      no-op for non-intel
  */
 int stress_tsc(
-        uint64_t *const counter,
-        const uint32_t instance,
-        const uint64_t max_ops,
-        const char *name)
+	uint64_t *const counter,
+	const uint32_t instance,
+	const uint64_t max_ops,
+	const char *name)
 {
 	return stress_not_implemented(counter, instance, max_ops, name);
 }
